@@ -12,7 +12,7 @@ from pam.models.request_command import RequestCommand
 from pam.task_manager import TaskManager
 from pam.temp_file_utils import TempfileUtils
 from threading import Lock
-
+from pam.utils import log
 
 class Server:
     """
@@ -35,15 +35,16 @@ class Server:
 
         @app.route('/service/<service_name>', methods=['POST'])
         def run(service_name):
+            log(f"[run] service = {service_name}")
             TempfileUtils.clean_temp()
-
+            log(f"[run] service = {service_name} after clean_temp")
             req, error_request = RequestCommand.parse(request, service_name)
-
             if error_request:
                 response = {'message': error_request}
                 return self.response_error(response, 400)
-
+            log(f"[run] service = {service_name} after parse")
             response, code = self.handle_service_cmd(service_name, req)
+            log(f"[run] service = {service_name} after handle_service_cmd")
             return self.response_error(response, code)
 
         @app.route('/tasks', methods=['GET'])
