@@ -5,10 +5,11 @@ from pam.service import Service
 
 
 RequestDataCallbackType = Callable[[str], Tuple[List[str], bool, str]]
+RequestSqliteCallbackType = Callable[[str, bool], Tuple[str]]
+UploadSqliteCallbackType = Callable[[str, bool, str], Tuple[str]]
 UploadResultCallbackType = Callable[[str], None]
 UploadReportCallbackType = Callable[[str], None]
 
-
 class TesterTask(ITaskManager):
     """
     Mock implementation of ITaskManager for testing services.
@@ -18,6 +19,8 @@ class TesterTask(ITaskManager):
 
     def __init__(self):
         self.request_data_callback: Optional[RequestDataCallbackType] = None
+        self.request_sqlite_callback: Optional[RequestSqliteCallbackType] = None
+        self.upload_sqlite_callback: Optional[UploadSqliteCallbackType] = None
         self.upload_result_callback: Optional[UploadResultCallbackType] = None
         self.upload_report_callback: Optional[UploadReportCallbackType] = None
 
@@ -27,6 +30,18 @@ class TesterTask(ITaskManager):
         """
         self.request_data_callback = request_data_callback
 
+    def set_on_request_sqlite(self, request_sqlite_callback: RequestSqliteCallbackType):
+        """
+        Set the callback for simulating data requests.
+        """
+        self.request_sqlite_callback = request_sqlite_callback
+
+    def set_on_upload_sqlite(self, upload_sqlite_callback: UploadSqliteCallbackType):
+        """
+        Set the callback for simulating SQLite uploads.
+        """
+        self.upload_sqlite_callback = upload_sqlite_callback
+
     def set_on_upload_result(self, upload_result_callback: UploadResultCallbackType):
         """
         Set the callback for simulating result uploads.
@@ -89,6 +104,24 @@ class TesterTask(ITaskManager):
         else:
             print("Request data callback is not set.")
 
+    def service_request_sqlite(self, service: Service, file_name: str = "", is_shared: bool = False) -> str:
+        if self.request_sqlite_callback is not None:
+            try:
+                return self.request_sqlite_callback(file_name, is_shared)     
+            except Exception as e:
+                print(f"Error in service_request_sqlite: {e}")
+        else:
+            print("Request sqlite callback is not set.")
+    
+    def service_upload_sqlite(self, service: Service, file_name: str = "", is_shared: bool = False, sqlite_file: str = "") -> str:
+        if self.upload_sqlite_callback is not None:
+            try:
+                return self.upload_sqlite_callback(file_name, is_shared, sqlite_file)     
+            except Exception as e:
+                print(f"Error in service_upload_sqlite: {e}")
+        else:
+            print("Upload sqlite callback is not set.")
+
     def service_upload_result(self, service: Service, file_path: str):
         """
         Simulate a service result upload.
